@@ -2,11 +2,10 @@ package AnyEvent::Open3::Simple::Process;
 
 use strict;
 use warnings;
-use v5.10;
 use Carp qw( croak );
 
 # ABSTRACT: process run using AnyEvent::Open3::Simple
-our $VERSION = '0.69'; # VERSION
+our $VERSION = '0.70'; # VERSION
 
 
 sub new
@@ -51,7 +50,7 @@ AnyEvent::Open3::Simple::Process - process run using AnyEvent::Open3::Simple
 
 =head1 VERSION
 
-version 0.69
+version 0.70
 
 =head1 DESCRIPTION
 
@@ -72,7 +71,8 @@ Windows.
 
 =head2 $proc-E<gt>say( @data )
 
-Write to the subprocess' stdin, adding a new line at the end.
+Write to the subprocess' stdin, adding a new line at the end.  This functionality
+is unsupported on Microsoft Windows.
 
 =head2 $proc-E<gt>close
 
@@ -80,7 +80,11 @@ Close the subprocess' stdin.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+author: Graham Ollis <plicease@cpan.org>
+
+contributors:
+
+Stephen R. Scaffidi
 
 =head1 COPYRIGHT AND LICENSE
 
